
# Type: notes


editorial notes about an element intended for internal consumption

URI: [meta:notes](https://w3id.org/biolink/biolinkml/meta/notes)


## Domain and Range

[Element](Element.md) ->  <sub>0..*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:editorialNote |
| **In Subsets:** | | owl |

